@@ -2,6 +2,7 @@ package Net::Server::Mail;
 
 use 5.006;
 use strict;
+use warnings;
 use Sys::Hostname;
 use IO::Select;
 use IO::Handle;
@@ -9,7 +10,7 @@ use Carp;
 
 use constant HOSTNAME => hostname();
 
-$Net::Server::Mail::VERSION = '0.21';
+$Net::Server::Mail::VERSION = '0.23';
 
 =pod
 
@@ -22,16 +23,16 @@ Net::Server::Mail - Class to easily create a mail server
     use Net::Server::Mail::SMTP;
 
     my @local_domains = qw(example.com example.org);
-    my $server = new IO::Socket::INET Listen => 1, LocalPort => 25;
+    my $server = IO::Socket::INET->new( Listen => 1, LocalPort => 25 );
     
     my $conn;
     while($conn = $server->accept)
     {
-        my $smtp = new Net::Server::Mail::SMTP socket => $conn;
+        my $smtp = Net::Server::Mail::SMTP->new( socket => $conn );
         $smtp->set_callback(RCPT => \&validate_recipient);
         $smtp->set_callback(DATA => \&queue_message);
         $smtp->process();
-	$conn->close();
+        $conn->close();
     }
 
     sub validate_recipient
@@ -89,7 +90,7 @@ ESMTP extensions. Developers can hook code at each SMTP session state
 and change the module's behaviors by registering event call-backs. The
 class is designed to be easily inherited from.
 
-This class is the base class for mail service protocols such axs
+This class is the base class for mail service protocols such as
 B<Net::Server::Mail::SMTP>, B<Net::Server::Mail::ESMTP> and
 B<Net::Server::Mail::LMTP>. Refer to the documentation provided with
 each of these modules.
@@ -98,7 +99,7 @@ each of these modules.
 
 =head2 new
 
-    $instance = new Net::Server::Mail [option => 'value', ...]
+    $instance = Net::Server::Mail->new( [option => 'value', ...] )
 
 options:
 
@@ -191,12 +192,11 @@ sub init {
 
 =head2 dojob
 
-Some command need to do some job after the handler call. Handler may
-want to overide this comportement to prevent from this job being
-executed.
+Some commands need to do a job after the handler call. The handler
+may want to override this to prevent the job from being executed.
 
-By calling this method with a (defined) false value as argument,
-expected job isn't executed. Defaults to true.
+By calling this method with a (defined) false value as an argument,
+the expected job isn't executed. Defaults to true.
 
 =cut
 
@@ -257,7 +257,8 @@ sub make_event {
     }
 
     # ensure that a reply is sent, all SMTP command need at most 1 reply.
-    unless ( defined $code ) {
+    # some events such as 'stop_session' don't require sending reply.
+    unless ( defined $code && !$args{'no_reply'} ) {
         if ( defined $success && $success ) {
             ( $code, $msg ) =
               $self->get_default_reply( $args{'success_reply'}, 250 );
@@ -268,7 +269,7 @@ sub make_event {
         }
     }
 
-    die "return code `$code' isn't numeric" if ( $code =~ /\D/ );
+    die "return code `$code' isn't numeric" if ( defined $code && $code =~ /\D/ );
 
     $self->handle_reply( $name, $success, $code, $msg )
       if defined $code and length $code;
@@ -418,7 +419,7 @@ sub process {
     my ($self) = @_;
 
     my $in  = $self->{in};
-    my $sel = new IO::Select;
+    my $sel = IO::Select->new;
     $sel->add($in);
 
     $self->banner;
@@ -455,10 +456,15 @@ sub process {
                 $rv = sysread( $in, $buffer, 512 * 1024, length($buffer) );
             }
         }
+        else {
+            # timeout
+            return $self->timeout;
+        }
+
         if ( ( not defined $rv ) or ( $rv == 0 ) ) {
 
-            # timeout, read error or connection closed
-            last;
+            # read error or connection closed
+            return $self->stop_session((not defined $rv) ? ($!) : ());
         }
 
         # process all terminated lines
@@ -498,7 +504,7 @@ sub process {
         }
     }
 
-    $self->timeout;
+    return 1;
 }
 
 sub process_once {
@@ -645,7 +651,7 @@ sub banner {
 
 =head2 timeout
 
-This event append where timeout is exeded.
+This event append where timeout is exceeded.
 
 Handler takes no argument.
 
@@ -668,6 +674,45 @@ sub timeout {
 
 =pod
 
+=head2 timeout
+
+This event append where connection is closed or an error occurs during reading from socket.
+
+Takes the error description as an argument if an error occured and the argument is undefined if the session was closed by peer.
+
+    $mailserver->set_callback
+    (
+        'stop_session', sub
+        {
+            my($session, $err) = @_;
+            if( defined $err )
+            {
+                print "Error occured during processing: $err\n";
+            }
+            else
+            {
+                print "Session closed py peer\n";
+            }
+            return 1;
+        }
+    );
+
+=cut
+
+sub stop_session {
+    my ($self, $err) = @_;
+
+    $self->make_event(
+        name          => 'stop_session',
+        arguments     => [$err],
+        no_reply      => 1,
+    );
+
+    return 1;
+}
+
+=pod
+
 =head1 SEE ALSO
 
 Please, see L<Net::Server::Mail::SMTP>, L<Net::Server::Mail::ESMTP>
