@@ -2,10 +2,11 @@ package Net::Server::Mail::ESMTP;
 
 use 5.006;
 use strict;
+use warnings;
 use Carp;
 use base qw(Net::Server::Mail::SMTP);
 
-our $VERSION = "0.22";
+our $VERSION = "0.23";
 
 =pod
 
@@ -18,12 +19,12 @@ Net::Server::Mail::ESMTP - A module to implement the ESMTP protocol
     use Net::Server::Mail::ESMTP;
 
     my @local_domains = qw(example.com example.org);
-    my $server = new IO::Socket::INET Listen => 1, LocalPort => 25;
+    my $server = IO::Socket::INET->new( Listen => 1, LocalPort => 25 );
 
     my $conn;
     while($conn = $server->accept)
     {
-        my $esmtp = new Net::Server::Mail::ESMTP socket => $conn;
+        my $esmtp = Net::Server::Mail::ESMTP->new( socket => $conn );
         # activate some extensions
         $esmtp->register('Net::Server::Mail::ESMTP::8BITMIME');
         $esmtp->register('Net::Server::Mail::ESMTP::PIPELINING');
@@ -31,7 +32,7 @@ Net::Server::Mail::ESMTP - A module to implement the ESMTP protocol
         $esmtp->set_callback(RCPT => \&validate_recipient);
         $esmtp->set_callback(DATA => \&queue_message);
         $esmtp->process();
-	$conn->close()
+        $conn->close();
     }
 
     sub validate_recipient
@@ -129,7 +130,7 @@ sub register {
         ) unless ( $class->can($method) );
     }
 
-    my $extend = new $class $self or return;
+    my $extend = $class->new($self) or return;
     foreach my $verb_def ( $extend->verb ) {
         $self->def_verb(@$verb_def) or return;
     }
