@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use base 'Net::Server::Mail';
 
-our $VERSION = "0.22";
+our $VERSION = "0.23";
 
 =pod
 
@@ -17,16 +17,16 @@ Net::Server::Mail::SMTP - A module to implement the SMTP protocol
     use Net::Server::Mail::SMTP;
 
     my @local_domains = qw(example.com example.org);
-    my $server = new IO::Socket::INET Listen => 1, LocalPort => 25;
+    my $server = IO::Socket::INET->new( Listen => 1, LocalPort => 25 );
 
     my $conn;
     while($conn = $server->accept)
     {
-        my $smtp = new Net::Server::Mail::SMTP socket => $conn;
+        my $smtp = Net::Server::Mail::SMTP->new( socket => $conn );
         $smtp->set_callback(RCPT => \&validate_recipient);
         $smtp->set_callback(DATA => \&queue_message);
         $smtp->process();
-        $conn->close()
+        $conn->close();
     }
 
     sub validate_recipient
@@ -728,11 +728,7 @@ USA
 
 =head1 COPYRIGHT
 
-<<<<<<< HEAD:lib/Net/Server/Mail/SMTP.pm
-Copyright (C) 2002 - Olivier Poitrey
-=======
 Copyright (C) 2002 - Olivier Poitrey, 2007 - Xavier Guimard
->>>>>>> new/master:lib/Net/Server/Mail/SMTP.pm
 
 =cut
 
